OC.L10N.register(
    "viewer",
    {
    "Viewer" : "ビューア",
    "Simple file viewer with slideshow for media" : "メディアスライドショー用の簡易ファイルビューア",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "映画のようにあなたの最新の休日の写真やビデオを表示したり、nextcloudからあなたの最新の小説を直接表示したり、お気に入りファイルの直接プレビューのおかげでコレクションの最高のGIFを選択できます。",
    "Your browser does not support audio." : "お使いのブラウザーはオーディオをサポートしていません。",
    "Error loading {name}" : "{name} の読み込みエラー",
    "Unsaved changes" : "保存していない変更点",
    "Your browser does not support videos." : "お使いのブラウザーはビデオに対応していません。",
    "Edit" : "編集",
    "Open sidebar" : "サイドバーを開く",
    "Download" : "ダウンロード",
    "Delete" : "削除",
    "There is no plugin available to display this file type" : "このファイルを表示するために必要なプラグインがありません。",
    "View" : "表示",
    "Name" : "名前",
    "Save" : "保存",
    "Back" : "戻る",
    "Loading …" : "読み込み中…",
    "Reset" : "リセット",
    "Cancel" : "キャンセル",
    "Continue" : "続ける",
    "Undo" : "元に戻す",
    "Redo" : "やり直し",
    "Original" : "オリジナル",
    "Custom" : "カスタム",
    "Value" : "値",
    "Image" : "画像",
    "Text" : "テキスト",
    "Size" : "サイズ",
    "Position" : "位置",
    "Extension" : "拡張",
    "Name is required." : "名前は必須です。",
    "Quality" : "品質"
},
"nplurals=1; plural=0;");
